summaryrefslogtreecommitdiff
path: root/source3/include/rpc_samr.h
diff options
context:
space:
mode:
Diffstat (limited to 'source3/include/rpc_samr.h')
-rw-r--r--source3/include/rpc_samr.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/include/rpc_samr.h b/source3/include/rpc_samr.h
index 37a0ed9a3f..c33d409997 100644
--- a/source3/include/rpc_samr.h
+++ b/source3/include/rpc_samr.h
@@ -572,8 +572,8 @@ typedef struct sam_unknown_info_12_inf
typedef struct sam_unknown_info_5_inf
{
- UNIHDR hdr_server; /* server name unicode header */
- UNISTR2 uni_server; /* server name unicode string */
+ UNIHDR hdr_domain; /* domain name unicode header */
+ UNISTR2 uni_domain; /* domain name unicode string */
} SAM_UNK_INFO_5;